# PowerBeatsVR_song_writer
Convert a BeatSaber level in to a PowerBeatsVR level.
Currently does not work. Because something in the PowerBeatsVR format makes no sense.


## Usage

### Website
There is a website where you can convert downloaded file, its source code is in this repository too so you can request changes:
https://powerbeatsvr.gnethomelinux.com/

### Commandline

```
pip3 install powerbeatsvr
powerbeatsvr [beat saber zip map] [output folder (created)]
```

Place the generated json in the PowerBeatsVR layouts folder, and play the ogg file in the game.
